@@ -1,10 +1,11 @@
 package tests
 
 import (
+	"context"
 	"testing"
 
-	"github.com/nginxinc/nginx-plus-go-client/client"
-	"github.com/nginxinc/nginx-plus-go-client/tests/helpers"
+	"github.com/nginxinc/nginx-plus-go-client/v2/client"
+	"github.com/nginxinc/nginx-plus-go-client/v2/tests/helpers"
 )
 
 // TestStatsNoStream tests the peculiar behavior of getting Stream-related
@@ -12,12 +13,13 @@ import (
 // The API returns a special error code that we can use to determine if the API
 // is misconfigured or of the stream block is missing.
 func TestStatsNoStream(t *testing.T) {
+	t.Parallel()
 	c, err := client.NewNginxClient(helpers.GetAPIEndpoint())
 	if err != nil {
 		t.Fatalf("Error connecting to nginx: %v", err)
 	}
-
-	stats, err := c.GetStats()
+	ctx := context.Background()
+	stats, err := c.GetStats(ctx)
 	if err != nil {
 		t.Errorf("Error getting stats: %v", err)
 	}
